@@ -1,5 +1,5 @@
 #' @title
-#' Calculate Covariate Balance
+#' Calculate covariate balance
 #'
 #' @description
 #' Calculates the weighted correlation between a list of covariates and an
@@ -16,13 +16,13 @@
 #'
 calc_ac <- function(w, X, weights){
 
-  w_mean <- sum(w*weights)
-  w_sd <- sqrt(sum((w-w_mean)^2*weights))
-  w_trans <- (w-w_mean)/w_sd
+  w_mean <- sum(w * weights)
+  w_sd <- sqrt(sum((w - w_mean) ^ 2 * weights))
+  w_trans <- (w - w_mean) / w_sd
 
-  X_mean <- colSums(X*weights)
-  X_cov <- (t(X) - X_mean)%*%diag(weights)%*%t(t(X)-X_mean)
-  X_trans <- t(t(solve(chol(X_cov)))%*%(t(X)-X_mean))
+  X_mean <- colSums(X * weights)
+  X_cov <- (t(X) - X_mean) %*% diag(weights) %*% t(t(X) - X_mean)
+  X_trans <- t(t(solve(chol(X_cov))) %*% (t(X) - X_mean))
 
-  return(c(w_trans%*%diag(weights)%*%X_trans))
+  return(c(w_trans %*% diag(weights) %*% X_trans))
 }
